function answer = amia_inputdlg(prompt,dlg_title,num_lines,defAns,Resize)

% Purpose:    The amia_inputdlg function is a bug fix for Matlab 7.0.4
%			  which throws an error if the num_lines parameter of the 
%             inputdlg function is two-dimensional.  This function queries
%			  Matlab to determine the version being used.  If version 
%			  7.0.4 then num_lines will be one-dimensional only.
%
% Usage:      answer = amia_inputdlg(prompt,dlg_title,num_lines,defAns,Resize)
%
% Inputs:     see Matlab documentation for inputdlg
% 
% Ouputs:     answer = output form inputdlg function
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin >= 3)
	v = version;
	if (strcmp('7.0.0', v(1:5)) && size(num_lines,2) == 1 && size(num_lines,1) > 1)
		num_lines = [num_lines, cellfun('length', prompt)+1];
	elseif (strcmp('7.0.0', v(1:5)) && size(num_lines,2) == 1 && size(num_lines,1) == 1)
		num_lines = [num_lines*ones(length(prompt),1), cellfun('length', prompt)+1];
	elseif (strcmp('7.0.4', v(1:5)) && size(num_lines,2) == 2)
		num_lines = num_lines(:,1);
	end
end

if (nargin == 1)
	answer = inputdlg(prompt);
elseif (nargin == 2)
	answer = inputdlg(prompt);
elseif (nargin == 3)
	answer = inputdlg(prompt,dlg_title, num_lines);
elseif (nargin == 4)
	answer = inputdlg(prompt, dlg_title, num_lines, defAns);
elseif (nargin == 5)
	answer = inputdlg(prompt, dlg_title, num_lines, defAns, Resize);
end
		
