function [swStat1, swStat1On] = ars_sw_stat1(ODMat, forePixNum, bckPixNum, critvalue);

% Purpose:    The ars_sw_stat1 function is a test statistic for  
%             identifying if a spot is on or off by comparing it to the
%             local background.
%
% Usage:      [swStat1, swStat1On] = ars_sw_stat1(ODMat, forePixNum, ...
%                   bckPixNum, critvalue)
%
% Inputs:     ODMat = a 1x4 vector of Spot Mean, Spot Std Dev, Background Mean, 
%                   Background Std Dev.
%             forePixNum = the number of pixels in spot mean
%             bckPixNum = the number of pixels in background mean.
%             critvalue = critical value to use as cutoff for z-score
% 
% Ouputs:     swStat1 = z-score statistic comparing spot to background
%             swStat1On = 1 if swStat1 >= critvalue, 0 otherwise
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if nargin==3,
   critvalue_p = 0.0001;
   critvalue_z = 2;
end

swStat1 = zeros(1,1);
swStat1On = zeros(1, 1);
diffln = log(ODMat(1)) - log(ODMat(3));
vardiff = ((1/forePixNum)*(ODMat(2)/ODMat(1))^2) + ((1/bckPixNum)*(ODMat(4)/ODMat(3))^2);
zval = diffln/sqrt(vardiff);
swStat1 = zval;
%p=1-normcdf(zval,0,1);
id=find(zval > critvalue_z);
swStat1On(id) = 1;

%AMW 12/5/2002
if (zval>4)
    swStat1On=2;
elseif (zval>2)
    swStat1On=1;
end
