function [row,col] = centroid(weight_array, round_ans);

% Purpose:    The centroid function takes an array of the form 
%             (row, column, weight) and calculates the two dimensional
%             weighted average of the points. 
%
% Usage:      [row, col] = centroid(weight_array, round_ans);
%
% Inputs:     weight_array = a 3-column array with point locations 
%               (row, column) and weights (or intensities)
%             round_ans = optional string variable that can take on 
%               values 'round' or 'noround', if no value specified
%               it is assumed to be 'noround'
% 
% Outputs:    row = the weighted average of the rows
%             col = the weighted average of the columns
%
% Requires:   (nothing)
%
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

weight_array = double(weight_array);
if (min(weight_array(:,3)) < 0) 
	weight_array(:,3) = weight_array(:,3)-min(weight_array(:,3))+1;
end

if (nargin==1)
    round_ans = 'noround';
end

if ( (strcmp(round_ans, 'round')==0) && (strcmp(round_ans, 'noround')==0) )
    disp('Error in centroid function: invalid value for round_ans');
    row = 0;
    col = 0;
    return;
end
row = weight_array(:,3)'*weight_array(:,1)/(weight_array(:,3)'*ones(size(weight_array,1),1));
col = weight_array(:,3)'*weight_array(:,2)/(weight_array(:,3)'*ones(size(weight_array,1),1));

if (strcmp(round_ans, 'round')==1)
    row = round(row);
    col = round(col);
end
