function files_to_open = choose_files(curr_path, file_types)

% Purpose:    The choose_files function allows the user to specify
%			  which files to analyze and to choose which image should
%			  be used to create the initial grid if it does not 
%			  already exist.
%
% Usage:      files_to_open = choose_files(curr_path, file_types)
%
% Inputs:     curr_path = the directory containing the images
%			  file_types = list of image file extensions to look at
% 
% Ouputs:     files_to_open = list of image files to analyze
% 
% Requires:   get_files
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

global INTERACTIVE_MODE;

files_to_open = get_files(curr_path, file_types);
num_files = size(files_to_open,1);

if (INTERACTIVE_MODE==1)
	%%%Allow user to choose to only analyze some files
	if (size(files_to_open,1)>1)

		%%Use GUI to do the ask user to choose files to analyze
		files_to_open = get_files(curr_path, file_types);
		[file_indices, ok] = listdlg('ListString', cellstr(files_to_open), ...
            'Name', 'Choose Files to Analyze', ...
			'ListSize', [450, 150], 'InitialValue', 1);
		if (ok == 1) 
			files_to_open = files_to_open(file_indices,:);
		else
			files_to_open = [];
		end
		num_files = size(files_to_open,1);
	end
	
	%%%%% Allow user to pick which slide is best to create the initial grid
	if (size(files_to_open, 1) > 1 && exist('well_map_info.mat') == 0)
		[init_file, ok] = listdlg('ListString', cellstr(files_to_open), 'Name', ...
			'Choose image for initial spot estimates (this should be the best slide):', ...
			'ListSize', [450, 150], 'InitialValue', 1, 'SelectionMode', 'single');
		if (ok == 1)
			files_to_open = [files_to_open(init_file, :); files_to_open];
			files_to_open(init_file+1,:) = [];
		end
	end	
end	

if (num_files == 0)
	error('There are no image files to analyze.  Exiting analyze_slides function...');
end
