function index = col_ind(names, column_header, match_type)

% Purpose:    The col_ind function allows the user to access data in
%             a matrix using column headers rather than column numbers.
%             For example, if we had a matrix called M and a list of 
%             column header names called colnames we could get the
%             column(s) corresponding to 'name' by
%                   M(:, col_ind('name', colnames))
%             
% Usage:      index = col_ind(names, column_header, match_type)
% 
% Inputs:     names = 1 or more names of columns
%             column_header = list of column names (in order)
%			  match_type = (optional) 'exact' (default), 
%				'begin' or 'contain', indicates which type of match
% 
% Outputs:    index = the column numbers corresponding to names
%
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin==2)
	match_type = 'exact';
end

index = [];
if (strcmp(match_type, 'exact')==1) 
	for (i = 1:size(names,1))
        index = [index; strmatch(deblank(names(i,:)),column_header,'exact')];
	end
elseif (strcmp(match_type, 'begin') ==1)
	for (i = 1:size(names,1))
        index = [index; strmatch(deblank(names(i,:)),column_header)];
	end
elseif (strcmp(match_type, 'contain') == 1)
	index = zeros(size(column_header,1),1);
	for (j = 1:size(column_header,1))
		for (i = 1:size(names, 1))
			if (isempty(strfind(deblank(column_header(j,:)), deblank(names(i, :)))))
				index(j) = 0;
				break;
			else
				index(j) = 1;
			end
		end
	end
	index = find(index>0);
end
