function [diagnostic_statistics, spacing, diag_names, error_ind, diag_ind] = config_diagnostic_statistics(curr_path, curr_file)

% Purpose:    The config_diagnostic_statistics function sets up the 
%			  variables related to diagnostic stats.
%
% Usage:      [diagnostic_statistics, spacing, diag_names, ...
%					error_ind, diag_ind] = ...
%					config_diagnostic_statistics(curr_path, curr_file)
%
% Inputs:     curr_path = the directory containing the images
%			  curr_file = the name of the current image file
% 
% Ouputs:     diagnostic_statistics = array of structures that contain
%					information about the analysis of each image
%			  spacing = array of structures containing information 
%					about the grid spacing of each image
%			  diag_names = array of file names indicating which 
%					element of diagnostic_statistics goes with
%					which file
%			  error_ind = vector indicating errors/problems
%					(0=OK, 1=error in processing, 2=spacing problem)
%			  diag_ind = index of current file in error_ind and diag_names
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

global SLIDE_LAYOUT_FILENAME;

if (exist(fullfile(curr_path, 'diagnostics.mat'))==2)  
    load(fullfile(curr_path, 'diagnostics.mat'));
end
if (exist('diag_names') == 0 || exist(fullfile(curr_path, 'diagnostics.mat'))~=2)
	diag_names = [];
	error_ind = [];
end
[tf, diag_ind] = ismember(curr_file, diag_names, 'rows');
load('blank_diagnostics.mat');
load(SLIDE_LAYOUT_FILENAME, 'rows_of_blocks', 'cols_of_blocks', 'num_wells_total');
empty_spacing.filename = curr_file;
empty_spacing.rows_of_spots = NaN*ones(rows_of_blocks, cols_of_blocks);
empty_spacing.cols_of_spots = NaN*ones(rows_of_blocks, cols_of_blocks);
if (tf==0)
	diag_names = strvcat(diag_names, curr_file);
	error_ind = [error_ind; 0];
	diag_ind = length(error_ind);
else  %%need to remove previous diagnostic entries
	error_ind(diag_ind) = 0;
end
blank_diagnostics.spacing = empty_spacing;
diagnostic_statistics(diag_ind) = blank_diagnostics;
diagnostic_statistics(diag_ind).filename = curr_file;
spacing(diag_ind,:) = repmat(empty_spacing, 1, num_wells_total);
clear blank_diagnostics;
clear empty_spacing;
clear rows_of_blocks, cols_of_blocks;
