function create_experiment_diagnostics_html(root_path, file_list, flags) 

% Purpose:    The create_experiment_diagnostics_html function creates an HTML
%			  page to display the experiment diagnostics.
%
% Usage:      create_experiment_diagnostics_html(root_path, file_list, flags)
%
% Inputs:     root_path = path containing the images to be analyzed
%			  file_list = list of image files analyzed
%			  flags = output of create_experimetn_diagnostics function
% 
% Ouputs:     none
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

html_name = fullfile(root_path, 'experiment_diagnostics', 'diagnostics.html');
fid = fopen(html_name, 'w');

x=fprintf(fid, '<html>\n');
x=fprintf(fid, '<title>Experiment Diagnostics</title>\n');
x=fprintf(fid, '<body>\n');
x=fprintf(fid, '<h1>Experiment Diagnostics</h1>');

if (nargin > 2)
	for (i = 1:size(flags,1))
		x=fprintf(fid, '%s<p>', deblank(flags(i,:)));
	end
end

x=fprintf(fid, '<table cellpadding=10 width=100%%>\n<tr><td>');
x=fprintf(fid, 'Ideal Spot used for this Experiment:<br>\n');
x=fprintf(fid, '<img src="experiment_ideal_spot.jpg" width=100%%><p>\n');
x=fprintf(fid, '</td></tr>\n<tr><td>');
x=fprintf(fid, 'Ideal Spot with Spot Mask:<br>\n');
x=fprintf(fid, '<img src="experiment_spot_mask.jpg" width=100%%><p>\n');
x=fprintf(fid, '</td>\n<td valign=top>');
load(fullfile(root_path, 'experiment_diagnostics','diag_variables.mat'));
x=fprintf(fid, 'Spot Mask Area: %G pixels<br>\n', sum(sum(spot_mask)));
x=fprintf(fid, 'Vertical Radius of Spot: %G pixels<br>\n', max(sum(spot_mask)));
x=fprintf(fid, 'Horizontal Radius of Spot: %G pixels<br>\n', max(sum(spot_mask')));
%delete(fullfile(root_path, 'experiment_diagnostics','diag_variables.mat'));
x=fprintf(fid, '</td>\n</table>');


x=fprintf(fid, '<a href="ideal_spots.html">Ideal Spots for Each Image</a>\n');
x=fprintf(fid, '</body>\n');
x=fprintf(fid, '</html>\n');
fclose(fid);

%%Create a page of all ideal spots for all images
spots_html = fullfile(root_path, 'experiment_diagnostics', 'ideal_spots.html');
fid = fopen(spots_html, 'w');
x=fprintf(fid, '<html>\n');
x=fprintf(fid, '<title>Ideal Spots for Each Image</title>\n');
x=fprintf(fid, '<body>\n');
x=fprintf(fid, '<h1>Ideal Spots for Each Image in the Experiment</h1>');
x=fprintf(fid, '<table width=100%%>\n');
for (i = 1:ceil(size(file_list,1)/3)) 
	x=fprintf(fid, '<tr>\n');
	for (j = 1:3)
		curr_file = (i-1)*3+j;
		if (curr_file > size(file_list,1)) break; end
		[path, filename, fext, fversion] = fileparts(deblank(file_list(curr_file,:)));
		x=fprintf(fid, '<td valign=TOP><small>%s:</small><br>\n', deblank(file_list(curr_file,:)));
		x=fprintf(fid, '<img src="../%s_DATA/ideal_spot.jpg" width=100%%><p></td>\n', filename);
	end
	x=fprintf(fid, '</tr>\n\n');
end
x=fprintf(fid, '</body>\n');
x=fprintf(fid, '</html>\n');
fclose(fid);
