function grid = create_grid_from_spacing(spacing)

% Purpose:    The create_grid_from_spacing function takes the spacing
%			  structure and creates a grid of expected spot centers.
%			  This version assumes that each block in a row or column
%			  may not be aligned--must be used with the version of 
%			  solve_grid_spacing that assumes the same.
%
% Usage:      grid = create_grid_from_spacing(spacing)
%
% Inputs:     spacing = structure giving spot spacing information, the
%					output of solve_grid_spacing function.
% 
% Ouputs:     grid = matrix giving expected pixel row and column, with 
%					spot row and column and block row and column.
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

	rows_of_blocks = spacing.rows_of_blocks;
	cols_of_blocks = spacing.cols_of_blocks;
	rows_of_spots = spacing.rows_of_spots;
	cols_of_spots = spacing.cols_of_spots;

	d_row = spacing.d_row;
	if (length(d_row)==1) d_row = d_row*ones(rows_of_blocks, cols_of_blocks); end
	d_col = spacing.d_col;
	if (length(d_col)==1) d_col = d_col*ones(rows_of_blocks, cols_of_blocks); end

	d_block_vert = spacing.d_block_vert;
	if (length(d_block_vert) == 1) d_block_vert = d_block_vert*repmat((1:rows_of_blocks)', 1, cols_of_blocks); end 
	d_block_horiz = spacing.d_block_horiz;
	if (length(d_block_horiz) == 1) d_block_horiz = d_block_horiz*repmat((1:rows_of_blocks)', 1, cols_of_blocks); end
		
	vert_offset = spacing.vert_offset;
	horiz_offset = spacing.horiz_offset;

	spot_centers = [];
	for (i = 1:cols_of_blocks)
        for (j = 1:rows_of_blocks)
			for (k = 1:rows_of_spots(j,i))
                for (m = 1:cols_of_spots(j,i))
                    spot_centers = [spot_centers; vert_offset+d_block_vert(j, i)+k*d_row(j, i), ...
							horiz_offset+d_block_horiz(j, i)+m*d_col(j, i), k, m, j, i];
                end
			end
        end
	end

	grid = spot_centers;
