function fig_handle = display_image_enhanced(img, quantiles)

% Purpose:    The display_image_enhanced function displays an image at the largest size
%			  possible on the screen while preserving aspect ratio, and contrast-
%			  enhances the image by compressing the upper and lower ends of the data range.
%
% Usage:      fig_handle = display_image_enhanced(img, quantiles)
%
% Inputs:     img = the image
%			  quantiles = vector of length 2 giving upper and lower quantile for
%					data compression (by default, this is [0.01, 0.99])
% 
% Ouputs:     fig_handle = handle of the figure created
% 
% Requires:   ideal_axes, mat2index_img, estimate_quantiles
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin == 1 || length(quantiles)~=2 ) quantiles = [0.01, 0.99]; end
q = estimate_quantiles(img, quantiles);
fig_handle = ideal_axes(size(img)); image(mat2index_img(img, q(1), q(2))); colormap(hot(256));
