function h = display_well_boundaries(img, well_row_bd, well_col_bd)

% Purpose:    The display_well_boundaries function creates a figure
%			  of the slide image with the well boundaries overlaid.
% 
% Usage:      h = display_well_boundaries(img, well_row_bd, well_col_bd)
% 
% Inputs:     img = the slide image
%			  well_row_bd = the row boundaries from find_wells function
%			  well_col_bd = the column boundaries from the find_wells function
%                    
% Outputs:    h = figure handle
% 
% Requires:   display_image_enhanced
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

h = display_image_enhanced(img); hold on;
title('Verify Well Boundaries');

rows = floor(size(well_row_bd,1)/2);
cols = floor(size(well_col_bd,1)/2);

for (j = 1:rows)
	for (k = 1:cols)
		begin_row = well_row_bd(2*j-1, 1);
		end_row = well_row_bd(2*j, 1);
		begin_col = well_col_bd(2*k-1, 1);
		end_col = well_col_bd(2*k, 1);
		
		line([begin_col; end_col], [begin_row; begin_row], 'Color', 'c', 'LineWidth', 2);
		line([begin_col; end_col], [end_row; end_row], 'Color', 'c', 'LineWidth', 2);
		line([begin_col; begin_col], [begin_row; end_row], 'Color', 'c', 'LineWidth', 2);
		line([end_col; end_col], [begin_row; end_row], 'Color', 'c', 'LineWidth', 2); 
	end
end
