function [tmp_quant] = estimate_quantiles(tmp_mat,tmp_pct)

% Purpose:    The estimate_quantiles function estimates the 
%			  quantiles of a matrix.
% 
% Usage:      [tmp_quant] = estimate_quantiles(tmp_mat,tmp_pct)
% 
% Inputs:     tmp_mat = matrix
%			  tmp_pct = (optional) vector of percent values
%                    
% Outputs:    tmp_quant = vector of estimated percentiles of tmp_mat
%					corresponding to tmp_pct
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if nargin == 1 | isempty(tmp_pct),
  tmp_pct = [.01,.05,.1,.25,.5,.75,.9,.95,.99];
end;

tmp_vec = sort(reshape(double(tmp_mat),prod(size(tmp_mat)),1));

tmp_n = size(tmp_vec,1);

tmp_min = min(tmp_vec);
tmp_max = max(tmp_vec);

tmp_frac = [0,((1:tmp_n) -.5)/tmp_n,1];
tmp_vec = [.95*tmp_min, tmp_vec', 1.05*tmp_max];

tmp_quant = interp1(tmp_frac,tmp_vec,tmp_pct);  

return;
