function centers = findPeakCenters(i_vec, peak_ids)

% Purpose:    The findPeakCenters function finds the centers of the peaks 
%             identified by the peak_ids vector
% 
% Usage:      centers = findPeakCenters(i_vec, peak_ids)
% 
% Inputs:     i_vec = vector of the mean intensities in each
%                   pixel row or column
%             peak_ids = integer vector where 0 indicates not
%                   part of a peak and n>0 indicates that row is
%                   part of peak n
%                    
% Outputs:    centers = the position of the center of each peak
%                   (column vector)
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

n_peaks = max(peak_ids);
tmp_ids =repmat(NaN,n_peaks,1); 
tmp_index = 1:length(i_vec); 
for tmp_I = 1:n_peaks,
    tmp_wt = i_vec(peak_ids == tmp_I);
    if (length(tmp_wt)>0)
        tmp_id = tmp_index(peak_ids == tmp_I);
        tmp_ids(tmp_I) = sum(tmp_wt.*tmp_id)/sum(tmp_wt);
    end
end;


centers = tmp_ids;
