function [ind1, ind2] = find_struct(struct_array, fieldname, value, negation)

% Purpose:    The find_struct function provides matching capability for arrays
%			  of structures similar to find() for arrays of double.
%
% Usage:      [ind1, ind2] = find_struct(struct_array, fieldname, value, negation)
%			  ind1 = find_struct(struct_array, fieldname, value, negation)
%
% Inputs:     struct_array = array of structures
%			  fieldname = the name of the field to match on
%			  value = value to find in the field corresponding to fieldname
%			  negation = T/F, find structs where fieldname ~= value?
% 
% Ouputs:     ind1, ind2 = indices of structures in struct_array that match
%					the criteria
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin == 3)
	negation = 'F';
end

ind1 = [];
ind2 = [];
if (nargout==1) %%return only ind1
	for (i = 1:prod(size(struct_array)))
		if (strcmp(class(value), 'char') == 1)
			if (~isempty(strmatch(deblank(struct_array(i).(fieldname)), value, 'exact')))
				ind1=[ind1; i];
			end
		elseif (strcmp(class(value), 'double') == 1)
			if (~isempty(find(value == struct_array(i).(fieldname))))
				ind1=[ind1; i];
			end
		end
	end
% 	if (nargout == 2 && size(struct_array, 2) > 1)  %%swap ind1 and ind2
% 		tmp = ind2;
% 		ind2 = ind1;
% 		ind1 = tmp;
% 	end
elseif (nargout == 2)
	for (i = 1:size(struct_array,1))
		for (j = 1:size(struct_array,2))
			if (strcmp(class(value), 'char') == 1)
				if (~isempty(strmatch(deblank(struct_array(i).(fieldname)), value, 'exact')))
					ind1=[ind1; i];
					ind2=[ind2; j];
				end
			elseif (strcmp(class(value), 'double') == 1)
				if (~isempty(find(value == struct_array(i).(fieldname))))
					ind1=[ind1; i];
					ind2=[ind2; j];
				end
			end
		end
	end
end
	
if (strcmp(upper(negation), 'T') || strcmp(upper(negation), 'NEGATE'))
	if (nargout == 2)
		[rows, cols] = find(ones(size(struct_array)));
	elseif (nargout == 1)
		rows = find(ones(size(struct_array)));
		cols = [];
	end
	[tf, ind] = ismember([rows, cols], [ind1, ind2], 'rows');
	ind1 = rows(find(tf==0));
	if (nargout == 2) ind2 = cols(find(tf==0)); end
end
