function colnames = get_column_names(filename, delim, skip) 

% Purpose:    The get_column_names function extracts column names
%             from a file.
%
% Usage:      colnames = get_column_names(filename, delim)
%
% Inputs:     filename = name of file
%             delim = (optional) delimiter (default is ',')
%             skip = (optional) lines to skip before column names 
%                   (default is 0)
% 
% Ouputs:     column names
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin == 1)
    delim = ',';
end
if (nargin < 3)
    skip = 0;
end

fid = fopen(filename, 'r');
for (i = 1:skip)
    tmp = fgetl(fid);
end
tmp = fgetl(fid);
colnames = [];
while true
    [currtok, tmp] = strtok(tmp, delim);
    if isempty(currtok),  break;  end
    colnames = strvcat(colnames, currtok);
end
fclose(fid);
