function file_list = get_files(path, extensions)

% Purpose:    The get_files function creates a list of all the files
%			  in the given directory.  If extensions are provided it 
%			  returns a list of files of those types. 
%
% Usage:      file_list = get_files(path, extensions)
% 
% Inputs:     path = a string giving the path of the directory
%			  extensions = (optional) a vector of extensions
%					(case-independent)
%                    
% Outputs:    files_list = a list of files in this directory
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

files_in_path=dir(path);
file_list=[];
for (i=1:length(files_in_path))
    if (files_in_path(i).isdir==0)
        this_file = files_in_path(i).name;
		if (nargin==2)
			[pathname,filename,ext,ver] = fileparts(this_file);
			[tf, ind] = ismember(upper(ext), upper(extensions), 'rows');
			if (tf == 0)
		        continue; %%continue to next file
			end
		end
		file_list=strvcat(file_list, this_file);
    end
end
