function fig_handle = ideal_axes(size, visible, scaling)

% Purpose:    The ideal_axes function creates a figure window and axes that
%             are as large as possible on your screen or largest possible
%             scaled by given scaling factor.
%             
% Usage:      fig_handle = ideal_axes(size, visible, scaling)
% 
% Inputs:     size = 2-element vector giving rows and columns
%             visible = 'on' or 'off' (optional)
%             scaling = number between 0 and 1 (optional)
% 
% Outputs:    fig_handle = the handle of the figure window created
%
% Requires:   (nothing)
%
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin == 1)
    visible = 'on';
	scaling = 1;
elseif (nargin == 2) 
	scaling = 1;
end

height = size(1);
width = size(2);
screen_size = get(0,'ScreenSize');
screen_width = screen_size(3); 
screen_height = screen_size(4);
screen_size = screen_size(3:4);
margin = 0.1;

if (height/width < 0.8*screen_size(2)/screen_size(1))
    fig_height = screen_width/screen_height*height/width*scaling;
    fig_handle = figure('Units', 'normalized', 'Position', [0, 0.10, scaling, fig_height], 'Visible', visible); 
    h = height/width*(1-2*margin)*(1.0*screen_width)/(fig_height*screen_height);
    axes('Position', [margin,(1-h)/2 , 1-2*margin, h])
else
    fig_width = 0.8*screen_height/screen_width;
    fig_width = 0.8*screen_height/screen_width*width/height*scaling;
    fig_handle = figure('Units', 'normalized', 'Position', [0, 0.10, fig_width, 0.8*scaling], 'Visible', visible);
    w = width/height*(1-2*margin)*(0.8*screen_height)/(fig_width*screen_width);
    axes('Position', [(1-w)/2,margin , w, 1-2*margin])
end    
