function original_img = load_image(filename)

% Purpose:    The load_image function reads the image file and if
%			  it is an RGB function it turns it into a 2D matrix
%			  (assuming that all channels are identical).
%
% Usage:      original_img = load_image(filename)
%
% Inputs:     filename = the name of the image file
% 
% Ouputs:     original_image = the 2D image
% 
% Requires:   read_img
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

filename = deblank(filename);
[curr_path, fname, fext, fversion] = fileparts(filename);
if (strcmp(fext, '.img') == 1)
    raw_img = read_img(filename);
else
	raw_img = imread(filename);
end

if (length(size(raw_img)) == 3)  %RBG image
    original_img = raw_img(:,:,1);
else
    original_img=raw_img;
end
