function score = maha_dist(data)

% Purpose:    The maha_dist function calculates the Mahalanobis distances for
%			  an array of data where each row is an observation.
%             
% Usage:      score = maha_dist(data)
% 
% Inputs:     data = array of numeric data
% 
% Outputs:    score = vector of scores, 1 score for each row of data
%
% Requires:   (nothing)
%
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

n_obs = size(data,1);
p = size(data, 2);
mu = mean(data);
sigma = cov(data);
score = NaN*ones(size(data,1), 1);

for (i = 1:n_obs)
    score(i) = (data(i,:)-mu)*inv(sigma)*(data(i,:)-mu)';
end
