function [tmp_index_img] = mat2index_img(tmp_mat,tmp_min,tmp_max,u_8_16)

% Purpose:	  The mat2index_img function takes a matrix and creates an
%			  indexed image (either uint8 or uint16).
%             
% Usage:	  [tmp_index_img] = mat2index_img(tmp_mat,tmp_min,tmp_max,u_8_16)
%			  [tmp_index_img] = mat2index_img(tmp_mat)
% 
% Inputs:	  tmp_mat = matrix (double, uint8, uint16) representing the
%					image
%			  tmp_min = minimum value for scaling (optional)
%			  tmp_max = maximum value for scaling (optional)
%			  u_8_16 = indicator for uint8 or uint16, can take values 8
%					or 16 (optional)
% 
% Outputs:	  tmp_index_img = an indexed image of type uint8 or uint16
%
% Requires:	  (nothing)
%
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if nargin == 1,
  tmp_min = [];
  tmp_max = [];
  u_8_16 = [];
elseif nargin == 3;
  u_8_16 = [];
end;

max_index = 255;

tmp_mat = double(tmp_mat);
tmp_vec = reshape(tmp_mat,prod(size(tmp_mat)),1);

if isempty(tmp_min),
  [tmp_range,tmp_min,tmp_max] = dsd_range(tmp_vec);
else,
  tmp_range = tmp_max - tmp_min;
end;

tmp_index_img = max_index*(tmp_mat - tmp_min)/tmp_range;
 
if isempty(u_8_16),
  tmp_index_img = uint8(tmp_index_img);
elseif u_8_16 == 8,
  tmp_index_img = uint8(tmp_index_img);
else,
  tmp_index_img = uint16(tmp_index_img);
end;

return;
