function new_img = outline_spots_image(img, grid, spot_mask)

% Purpose:    The outline_spots_image function creates an image where the 
%			  spots are outlined.
%             
% Usage:      new_img = outline_spots_image(img, grid, spot_mask)
% 
% Inputs:     img = the slide image, values scaled from 0 to 255
%			  grid = coordinates (row, column) of spot centers
%             spot_mask = a 0/1 matrix giving the size and shape of the 
%                     spot (0=background, 1=spot)
% 
% Outputs:    new_img = the slide img with spots outlined in black
%
% Requires:   bwmorph (Matlab Image Processing Toolbox)
%                     
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

new_img = img;
new_img(new_img == 255) = 254;
spot_mask(spot_mask>0) = 1;
spot_mask = double(spot_mask);
spot_outline = bwmorph(spot_mask, 'dilate');
spot_outline = bwmorph(spot_outline, 'dilate');
spot_outline = spot_outline-spot_mask;

if (max(size(grid)) > 1)
	[r, c] = find(spot_outline>0);
	[mask_center_row, mask_center_col] = centroid([r, c, ones(length(r), 1)], 'round');
	num_spots = size(grid, 1);
	r_diff = r-mask_center_row;
	c_diff = c-mask_center_col;
	
	for (i = 1:num_spots)
            coords = [round(grid(i, 1))+r_diff, round(grid(i, 2))+c_diff];
            coords = coords(coords(:, 1)>0, :); %%remove negative coordinates
            coords = coords(coords(:, 2)>0, :);
            for (j = 1:size(coords,1))
                new_img(coords(j, 1), coords(j, 2)) = 255;
            end
	end
else 
	new_img(spot_outline>0) = 255;
end
