function padded_mat = pad_matrix(matrix, rows, cols)

% Purpose:    The pad_matrix function pads a matrix with the same 
%             value as the outer edge of the matrix.
%             
% Usage:      padded_mat = pad_matrix(matrix, rows, cols)
% 
% Inputs:     vec = the vector to be padded
%             rows = # of rows to add to matrix
%             cols = # to add to end of vector
% 
% Outputs:    padded_mat = the padded matrix
% 
% Requires:   (nothing)
%                     
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin == 2)
    cols = rows;
end

data_type = class(matrix);
matrix = double(matrix);

padded_mat = [repmat(matrix(1,:), rows, 1); matrix; repmat(matrix(size(matrix,1), :), rows, 1)];
first_col = [matrix(1,1)*ones(rows,1); matrix(:,1); matrix(size(matrix,1), 1)*ones(rows,1)];
last_col = [matrix(1,size(matrix,2))*ones(rows,1); matrix(:,size(matrix,2)); ...
		matrix(size(matrix,1), size(matrix,2))*ones(rows,1)];
padded_mat = [repmat(first_col, 1, cols), padded_mat, repmat(last_col, 1, cols)];

if (strcmp(data_type, 'uint16') == 1)
	padded_mat = uint16(padded_mat);
elseif (strcmp(data_type, 'uint8') == 1)
	padded_mat = uint8(padded_mat);
elseif (strcmp(data_type, 'uint32') == 1)
	padded_mat = uint32(padded_mat);
elseif (strcmp(data_type, 'uint64') == 1)
	padded_mat = uint64(padded_mat);
elseif (strcmp(data_type, 'int16') == 1)
	padded_mat = int16(padded_mat);
elseif (strcmp(data_type, 'int8') == 1)
	padded_mat = int8(padded_mat);
elseif (strcmp(data_type, 'int32') == 1)
	padded_mat = int32(padded_mat);
elseif (strcmp(data_type, 'int64') == 1)
	padded_mat = int64(padded_mat);
end
	
