function img = plot_points_img(original_img, grid, spot_rad, enhance)

% Purpose:    The plot_points_img function plots a set of points on an image
%			  by condensing the image values into the range 0-254 and setting
%			  points pixels to 255, thus making it possible to create and 
%			  save an image overlaid with points without displaying on
%			  the screen.
%             
% Usage:      img = plot_points_img(original_img, grid, spot_rad, enhance)
% 
% Inputs:     original_img = the image
%             grid = grid of points to plot, where column 1 is pixel row and
%					column 2 is pixel column
%			  spot_rad = radius of spots to plot
%			  enhance = 'enhance' or 'noenhance', whether or not to contrast-
%					enhance the image
% 
% Outputs:    img = image with points (to plot and display points, use a colormap
%					similar to this:  my_colormap = [hot(255); 0, 1, 1])
%
% Requires:   estimate_quantiles, mat2index_img
%
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

if (nargin < 4)
	enhance = 'noenhance';
end

if (strcmp(lower(enhance), 'enhance') == 1)
	q = estimate_quantiles(original_img, [0.01, 0.99]);
	img = mat2index_img(original_img, q(1), q(2));
else
	img = mat2index_img(original_img);
end
img(img==255) = 254;

my_colormap = [hot(256); 0, 1, 1];
%spot_rad = 1;

for (i = 1:size(grid,1))
	min_row_img = round(max(1, grid(i,1)-spot_rad));
	max_row_img = round(min(size(img, 1), grid(i,1)+spot_rad));
	min_col_img = round(max(1, grid(i,2)-spot_rad));
	max_col_img = round(min(size(img,2), grid(i,2)+spot_rad));
		
	img(min_row_img:max_row_img, min_col_img:max_col_img) = ...
		255*ones(max_row_img-min_row_img+1, max_col_img-min_col_img+1);
end
	
