function [raw_img, sizes, calibrated, pixels] = read_img(filename)

% Purpose:    The read_img function imports image files of type .img
% 
% Usage:      raw_img = read_img(filename)
% 
% Inputs:     filename = name of image file 
%                    
% Outputs:    raw_img = matrix representing the image
%
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

fid=fopen(filename, 'r');
simg=fread(fid, 4, 'uchar');
test_str=char(simg');  %should be 'SIMG'
if (strcmp(test_str, 'SIMG')==0)
    display(['Not of type .img (', filename, ')']);
    raw_img=[];
    return;
end
sizes=fread(fid, 2, 'int16');
calibrated=fread(fid, 1, 'double');
data=fread(fid, prod(sizes), 'int16');
% bitget(data(1), 16:-1:1)
test=fread(fid, 'int16'); %this should be empty--should be no data left
fclose(fid);

if (calibrated>0)
    data=data*calibrated;
end
pixels = data(1:7)';

%%% Need to make sure I have correct orientation here--i.e. (x, y) not (y, x)
tmp_img = reshape(data, sizes(1), sizes(2));
raw_img = tmp_img';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% disp('Inverting image!!! Remove after analyzing Gelpads from Experiment 2!!!');
% raw_img = rev_columns(raw_img);
% for (i = 1:size(raw_img,2))
%     raw_img(:, i) = rev(raw_img(:,i));
% end
