function [Current_Region] = seeded_region_grower4(subimage, seedrc, z_critval, Nmin, Nmax, plots_on);

% Purpose:    The seeded_region_grower4 function takes a segment of an 
%             image and a seed and determines which pixels are similar
%             enough to the seed that they are part of the same class.
%
% Usage:      [Current_Region] = seeded_region_grower3(subimage, seedrc, ...
%                     z_critval,Nmax, plots_on)
%
% Inputs:     subimage = segment of an image
%             seedrc = two-element vector consisting of the row and column
%                     of the starting seed
%             z_critval = z-score cutoff for admitting new pixels into
%                     the spot
%             Nmin = min number of pixels in the spot
%             Nmax = max number of pixels in the spot
%             plots_on = a 0/1 indicator of whether to display plots
% 
% Ouputs:     Current_Region = a 2-column matrix giving row, column 
%                     coordinates of each pixel in the spot
% 
% Requires:   imdilate (Matlab Image Processing Toolbox)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

[nr,nc] = size(subimage);
subimage = double(subimage);

tmp_vec = [subimage(1,:), subimage(2,:), ...
       subimage(nr-1,:),  subimage(nr,:), ...
       subimage(:,1)',    subimage(:,2)', ...
       subimage(:,nc-1)', subimage(:,nc)'];


CR_bck_trend = estimate_quantiles(tmp_vec,.30);
CR_sd = sqrt(var(tmp_vec));
if (CR_sd == 0)  
    CR_sd = 1; 
end

Current_Region = zeros([nr,nc]);
Current_Region(seedrc(1),seedrc(2)) = 1;

Npixels = 1;
while (Npixels < Nmax)
	Current_Boundary = imdilate(Current_Region,ones(3,3));
	Current_Boundary(Current_Region == 1) = 0;
	
	%  CHARACTERIZE CURRENT REGION.
	
	% tmp_vec = subimage(Current_Region == 1);
	% CR_mean = mean(tmp_vec);
	% CR_sd = sqrt(var(tmp_vec)); if CR_sd == 0,  CR_sd = 1; end;
	
	%  SCORE AND EVALUATE CURRENT BOUNDARY PIXELS
	
	[CB_ID] = find(Current_Boundary == 1);
	CB_z = (subimage(CB_ID) - CR_bck_trend)/CR_sd;
	CB_ID = CB_ID((CB_z) > z_critval);
	
	if (length(CB_ID) > 0)
	    Current_Region(CB_ID) = 1;
	else
	    break; 
	end
	
	Npixels = length(Current_Region(Current_Region == 1));

end

if (Npixels < Nmin) 
    Current_Region = zeros(size(Current_Region)); 
end

%  DISPLAY CURRENT REGION AND BOUNDARY.

if (plots_on == 1)
%     figure(1); clf; 
% 	set(gcf,'units','normalized', 'position', [0.15 0.19  0.35  0.72]);
% 	set(gca,'position',[.05 .05,.9 .9]);
    ideal_axes(size(subimage));
	colormap(hot(400)); tmp_rgb =  colormap;
	colormap(tmp_rgb(30:(30+255),:));
	
	image(mat2index_img(subimage)); hold on; pause(1);
	
	[tmpy,tmpx] = find(Current_Region == 1);
	plot(tmpx,tmpy,'.','MarkerSize',10,'Color',[1 1 1]);
end

[r, c] = find(Current_Region > 0);
Current_Region = [r, c];


