function stats = spot_shape_stats(spot_map, num_spots)

% Purpose:    The spot_shape_stats function generates statistics about
%			  the size and shape of the spots in the given spot map.
%
% Usage:      stats = spot_shape_stats(spot_map, num_spots)
%
% Inputs:     spot_map = the spot map (see ideal_spot_map.m for 
%					description of a spot map)
%			  num_spots = number of spots
% 
% Ouputs:     stats = matrix of statistics, where row i gives these 
%					statistics for spot i: (area, vertical diameter, 
%					horizontal diameter, eccentricity (vert/horiz diameter),
%					and expected area based on diameters)
% 
% Requires:   (nothing)
% 
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

spot_map = double(spot_map);
% stats = NaN*ones(num_spots, 5);
stats = NaN*ones(num_spots, 4);
[r, c, I] = find(spot_map);
coords = [r, c, I];
for (i = 1:num_spots)
	pixels = coords(coords(:,3)==i,:);
	if (isempty(pixels))
		continue;
	end
	%%test for size and shape
	area = size(pixels,1);
	row_diam = max(pixels(:,1))-min(pixels(:,1))+1;
	col_diam = max(pixels(:,2))-min(pixels(:,2))+1;
	eccentricity = row_diam/col_diam;
	exp_area = pi*(mean([row_diam, col_diam])/2)^2;
% 	stats(i,:) = [area, row_diam, col_diam, eccentricity, exp_area];
	stats(i,:) = [area, row_diam, col_diam, exp_area];
end
