function write_stats_to_file(stats, columns, filenames, permissions)

% Purpose:    The write_stats_to_file function writes the statistics out
%			  to one or more files.
%             
% Usage:      write_stats_to_file(stats, columns, ...
%					individual_results_filename, all_results_fid)
% 
% Inputs:     stats = the matrix of statistics
%			  columns = a vector of column names
%			  filenames = vector of filenames
%			  permissions = vector of write permissions 
%					(either 'w' or 'a')
% 
% Outputs:    (nothing)
% 
% Requires:   (nothing)
%                     
% Copyright (c) 2004 Battelle Memorial Institute
% This file is part of the Automated Microarray Image
% Analysis Toolbox for MATLAB.
% http://www.pnl.gov/statistics/amia

for (k = 1:size(filenames, 1))
	write_columns = 0;
	try 
		if (exist(deblank(filenames(k,:))) ~= 2)
			write_columns = 1;
		end
		fid=fopen(deblank(filenames(k,:)), permissions(k));
		%%only write column names if not appending to file or file does not exist
		if(strcmp(permissions(k), 'w') || write_columns == 1)
			for (i=1:(size(columns,1)-1))
                x=fprintf(fid, '%s,', deblank(columns(i,:)));
			end
			x=fprintf(fid, '%s\n', deblank(columns(size(columns,1),:)));
		end
		format_str = [repmat('%f,', 1,size(stats, 2)-1),'%f\n'];
		x=fprintf(fid, format_str, stats');
		status=fclose(fid);
	catch
		disp(['Problem in write_stats_to_file: couldn''t write results to file ', deblank(filenames(k,:))]);
	end
end
